# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from amgix_client.models.custom_document_vector import CustomDocumentVector
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class Document(BaseModel):
    """
    Document model representing the structure of documents in the system.  This model is used for document ingestion, retrieval, and search results. Content is excluded from database storage for performance and cost reasons.
    """ # noqa: E501
    id: Annotated[str, Field(strict=True, max_length=100)] = Field(description="Unique identifier for the document (max 100 characters)")
    timestamp: datetime = Field(description="UTC timestamp when the document was created/updated")
    tags: Optional[Annotated[List[StrictStr], Field(max_length=50)]] = Field(default=None, description="List of document tags (max 50 items; each max 100 characters; cannot contain pipe characters)")
    name: Optional[Annotated[str, Field(strict=True, max_length=1500)]] = Field(default=None, description="Document name (max 1500 characters)")
    description: Optional[Annotated[str, Field(strict=True, max_length=3000)]] = Field(default=None, description="Brief description of the document (max 3000 characters)")
    content: Optional[Annotated[str, Field(strict=True, max_length=1000000)]] = Field(default=None, description="Main content of the document (max 1000000 characters)")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Dictionary of metadata key-value pairs. Values can be simple types (string, int, float, bool) or MetaValue objects (required for datetime)")
    custom_vectors: Optional[List[CustomDocumentVector]] = Field(default=None, description="Pre-generated custom vectors for this document (optional)")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["id", "timestamp", "tags", "name", "description", "content", "metadata", "custom_vectors"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Document from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in custom_vectors (list)
        _items = []
        if self.custom_vectors:
            for _item_custom_vectors in self.custom_vectors:
                if _item_custom_vectors:
                    _items.append(_item_custom_vectors.to_dict())
            _dict['custom_vectors'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Document from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "timestamp": obj.get("timestamp"),
            "tags": obj.get("tags"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "content": obj.get("content"),
            "metadata": obj.get("metadata"),
            "custom_vectors": [CustomDocumentVector.from_dict(_item) for _item in obj["custom_vectors"]] if obj.get("custom_vectors") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

# flake8: noqa
"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from amgix_client.models.bulk_upload_request import BulkUploadRequest
from amgix_client.models.collection_config import CollectionConfig
from amgix_client.models.collection_exists_response import CollectionExistsResponse
from amgix_client.models.custom_document_vector import CustomDocumentVector
from amgix_client.models.custom_vector import CustomVector
from amgix_client.models.document import Document
from amgix_client.models.document_status import DocumentStatus
from amgix_client.models.document_status_response import DocumentStatusResponse
from amgix_client.models.http_validation_error import HTTPValidationError
from amgix_client.models.metadata_filter import MetadataFilter
from amgix_client.models.metadata_index import MetadataIndex
from amgix_client.models.ok_response import OkResponse
from amgix_client.models.queue_info import QueueInfo
from amgix_client.models.ready_response import ReadyResponse
from amgix_client.models.search_query import SearchQuery
from amgix_client.models.search_result import SearchResult
from amgix_client.models.validation_error import ValidationError
from amgix_client.models.validation_error_loc_item import ValidationErrorLocItem
from amgix_client.models.vector import Vector
from amgix_client.models.vector_config import VectorConfig
from amgix_client.models.vector_score import VectorScore
from amgix_client.models.vector_search_weight import VectorSearchWeight
from amgix_client.models.version_response import VersionResponse




# coding: utf-8

# flake8: noqa

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.1.0"

# Define package exports
__all__ = [
    "AmgixApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BulkUploadRequest",
    "CollectionConfig",
    "CollectionExistsResponse",
    "CustomDocumentVector",
    "CustomVector",
    "Document",
    "DocumentStatus",
    "DocumentStatusResponse",
    "HTTPValidationError",
    "MetadataFilter",
    "MetadataIndex",
    "OkResponse",
    "QueueInfo",
    "ReadyResponse",
    "SearchQuery",
    "SearchResult",
    "ValidationError",
    "ValidationErrorLocItem",
    "Vector",
    "VectorConfig",
    "VectorScore",
    "VectorSearchWeight",
    "VersionResponse",
]

# import apis into sdk package
from amgix_client.api.amgix_api import AmgixApi as AmgixApi

# import ApiClient
from amgix_client.api_response import ApiResponse as ApiResponse
from amgix_client.api_client import ApiClient as ApiClient
from amgix_client.configuration import Configuration as Configuration
from amgix_client.exceptions import OpenApiException as OpenApiException
from amgix_client.exceptions import ApiTypeError as ApiTypeError
from amgix_client.exceptions import ApiValueError as ApiValueError
from amgix_client.exceptions import ApiKeyError as ApiKeyError
from amgix_client.exceptions import ApiAttributeError as ApiAttributeError
from amgix_client.exceptions import ApiException as ApiException

# import models into sdk package
from amgix_client.models.bulk_upload_request import BulkUploadRequest as BulkUploadRequest
from amgix_client.models.collection_config import CollectionConfig as CollectionConfig
from amgix_client.models.collection_exists_response import CollectionExistsResponse as CollectionExistsResponse
from amgix_client.models.custom_document_vector import CustomDocumentVector as CustomDocumentVector
from amgix_client.models.custom_vector import CustomVector as CustomVector
from amgix_client.models.document import Document as Document
from amgix_client.models.document_status import DocumentStatus as DocumentStatus
from amgix_client.models.document_status_response import DocumentStatusResponse as DocumentStatusResponse
from amgix_client.models.http_validation_error import HTTPValidationError as HTTPValidationError
from amgix_client.models.metadata_filter import MetadataFilter as MetadataFilter
from amgix_client.models.metadata_index import MetadataIndex as MetadataIndex
from amgix_client.models.ok_response import OkResponse as OkResponse
from amgix_client.models.queue_info import QueueInfo as QueueInfo
from amgix_client.models.ready_response import ReadyResponse as ReadyResponse
from amgix_client.models.search_query import SearchQuery as SearchQuery
from amgix_client.models.search_result import SearchResult as SearchResult
from amgix_client.models.validation_error import ValidationError as ValidationError
from amgix_client.models.validation_error_loc_item import ValidationErrorLocItem as ValidationErrorLocItem
from amgix_client.models.vector import Vector as Vector
from amgix_client.models.vector_config import VectorConfig as VectorConfig
from amgix_client.models.vector_score import VectorScore as VectorScore
from amgix_client.models.vector_search_weight import VectorSearchWeight as VectorSearchWeight
from amgix_client.models.version_response import VersionResponse as VersionResponse




# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class VectorConfig(BaseModel):
    """
    Configuration for a vector generation method.  This model defines how vectors should be generated for a specific field or set of fields. Different vector types have different requirements and behaviors.
    """ # noqa: E501
    name: StrictStr = Field(description="Unique name for this vector configuration")
    type: StrictStr = Field(description="Type of vector (dense_model, sparse_model, full_text, trigrams, whitespace, wmtr, dense_custom, sparse_custom)")
    model: Optional[Annotated[str, Field(strict=True, max_length=210)]] = Field(default=None, description="Model name for transformer-based vectors (max 210 characters, e.g., 'sentence-transformers/all-MiniLM-L6-v2'). Used for document indexing.")
    revision: Optional[Annotated[str, Field(strict=True, max_length=210)]] = Field(default=None, description="Optional model revision (max 210 characters, branch/tag/commit) for specific model version. Used for document indexing.")
    query_model: Optional[Annotated[str, Field(strict=True, max_length=210)]] = Field(default=None, description="Optional model name for query vectorization (max 210 characters). If not specified, uses 'model' for both documents and queries.")
    query_revision: Optional[Annotated[str, Field(strict=True, max_length=210)]] = Field(default=None, description="Optional model revision for query vectorization (max 210 characters). If not specified, uses 'revision' for both documents and queries.")
    dimensions: Optional[StrictInt] = Field(default=None, description="Dimensions for the vector. Required for dense_custom vectors. For dense_model vectors, auto-detected if not specified.")
    top_k: Optional[StrictInt] = Field(default=128, description="Number of top-scoring terms to keep for sparse vectors. Used by sparse_model, full_text, trigrams, whitespace, wmtr, and sparse_custom vectors. Ignored by dense vectors.")
    wmtr_word_weight: Optional[Annotated[int, Field(le=100, strict=True, ge=0)]] = Field(default=80, description="Percentage of WMTR top_k allocated to word weights.")
    index_fields: Optional[List[StrictStr]] = Field(default=None, description="List of fields to index with this vector (name, description, content). Defaults to ['content'] if not specified.")
    language_default_code: Optional[StrictStr] = Field(default='en', description="Two-letter ISO 639-1 language code for language-based vector types (e.g., 'en', 'es', 'fr')")
    language_detect: Optional[StrictBool] = Field(default=False, description="Whether to automatically detect language for language-based vector types")
    language_confidence: Optional[Union[StrictFloat, StrictInt]] = Field(default=0.9, description="Minimum confidence threshold for language detection. If detection confidence is below this value, language_default_code will be used instead.")
    normalization: Optional[StrictBool] = Field(default=None, description="Whether to normalize vectors. Only supported for dense vectors. Sparse vectors do not support normalization.")
    dense_distance: Optional[StrictStr] = Field(default='cosine', description="Distance metric for dense vectors (cosine, dot, euclid). Defaults to cosine.")
    keep_case: Optional[StrictBool] = Field(default=False, description="Whether to keep original case for text preprocessing. Only applies to model-based vectors (dense_model, sparse_model). Defaults to False (lowercase).")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["name", "type", "model", "revision", "query_model", "query_revision", "dimensions", "top_k", "wmtr_word_weight", "index_fields", "language_default_code", "language_detect", "language_confidence", "normalization", "dense_distance", "keep_case"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['dense_model', 'sparse_model', 'full_text', 'trigrams', 'whitespace', 'wmtr', 'keyword', 'dense_custom', 'sparse_custom']):
            raise ValueError("must be one of enum values ('dense_model', 'sparse_model', 'full_text', 'trigrams', 'whitespace', 'wmtr', 'keyword', 'dense_custom', 'sparse_custom')")
        return value

    @field_validator('index_fields')
    def index_fields_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['name', 'description', 'content']):
                raise ValueError("each list item must be one of ('name', 'description', 'content')")
        return value

    @field_validator('dense_distance')
    def dense_distance_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['cosine', 'dot', 'euclid']):
            raise ValueError("must be one of enum values ('cosine', 'dot', 'euclid')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VectorConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VectorConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "type": obj.get("type"),
            "model": obj.get("model"),
            "revision": obj.get("revision"),
            "query_model": obj.get("query_model"),
            "query_revision": obj.get("query_revision"),
            "dimensions": obj.get("dimensions"),
            "top_k": obj.get("top_k") if obj.get("top_k") is not None else 128,
            "wmtr_word_weight": obj.get("wmtr_word_weight") if obj.get("wmtr_word_weight") is not None else 80,
            "index_fields": obj.get("index_fields"),
            "language_default_code": obj.get("language_default_code") if obj.get("language_default_code") is not None else 'en',
            "language_detect": obj.get("language_detect") if obj.get("language_detect") is not None else False,
            "language_confidence": obj.get("language_confidence") if obj.get("language_confidence") is not None else 0.9,
            "normalization": obj.get("normalization"),
            "dense_distance": obj.get("dense_distance") if obj.get("dense_distance") is not None else 'cosine',
            "keep_case": obj.get("keep_case") if obj.get("keep_case") is not None else False
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class VectorSearchWeight(BaseModel):
    """
    Configuration for a vector search weight. Used in search queries to specify which vectors to search with and their weights.
    """ # noqa: E501
    vector_name: StrictStr = Field(description="Name of the vector to search with")
    weight: Optional[Union[StrictFloat, StrictInt]] = Field(default=1.0, description="Weight to apply to this vector's search results")
    var_field: StrictStr = Field(description="Field to search with this vector (name, description, content)", alias="field")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["vector_name", "weight", "field"]

    @field_validator('var_field')
    def var_field_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['name', 'description', 'content']):
            raise ValueError("must be one of enum values ('name', 'description', 'content')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VectorSearchWeight from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VectorSearchWeight from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "vector_name": obj.get("vector_name"),
            "weight": obj.get("weight") if obj.get("weight") is not None else 1.0,
            "field": obj.get("field")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Amalgam Index API

    Amalgam Index (Amgix). Open-Source Hybrid Search System

    The version of the OpenAPI document: 1.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class MetadataFilter(BaseModel):
    """
    Recursive metadata filter structure (modeled on Qdrant filter with and/or/not).
    """ # noqa: E501
    var_and: Optional[List[MetadataFilter]] = Field(default=None, description="All conditions in this list must match (AND)", alias="and")
    var_or: Optional[List[MetadataFilter]] = Field(default=None, description="Any condition in this list must match (OR)", alias="or")
    var_not: Optional[MetadataFilter] = Field(default=None, description="This condition must NOT match (NOT)", alias="not")
    key: Optional[StrictStr] = Field(default=None, description="Metadata field key (for field condition)")
    op: Optional[StrictStr] = Field(default=None, description="Comparison operator")
    value: Optional[Any] = None
    __properties: ClassVar[List[str]] = ["and", "or", "not", "key", "op", "value"]

    @field_validator('op')
    def op_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['eq', 'lt', 'gt', 'lte', 'gte']):
            raise ValueError("must be one of enum values ('eq', 'lt', 'gt', 'lte', 'gte')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetadataFilter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in var_and (list)
        _items = []
        if self.var_and:
            for _item_var_and in self.var_and:
                if _item_var_and:
                    _items.append(_item_var_and.to_dict())
            _dict['and'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_or (list)
        _items = []
        if self.var_or:
            for _item_var_or in self.var_or:
                if _item_var_or:
                    _items.append(_item_var_or.to_dict())
            _dict['or'] = _items
        # override the default output from pydantic by calling `to_dict()` of var_not
        if self.var_not:
            _dict['not'] = self.var_not.to_dict()
        # set to None if value (nullable) is None
        # and model_fields_set contains the field
        if self.value is None and "value" in self.model_fields_set:
            _dict['value'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetadataFilter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "and": [MetadataFilter.from_dict(_item) for _item in obj["and"]] if obj.get("and") is not None else None,
            "or": [MetadataFilter.from_dict(_item) for _item in obj["or"]] if obj.get("or") is not None else None,
            "not": MetadataFilter.from_dict(obj["not"]) if obj.get("not") is not None else None,
            "key": obj.get("key"),
            "op": obj.get("op"),
            "value": obj.get("value")
        })
        return _obj

# TODO: Rewrite to not use raise_errors
MetadataFilter.model_rebuild(raise_errors=False)

